# __main__.py

def main():
    print("Project is on the way to update this feature...,\nThank you all for your support")
    return


if __name__ == '__main__':
    main()
